==> ulyxex.0.0.8.with-tinyMce.zip: pages/code/admin_home.php <==
<?php
class Site extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function site_params() {
		if ($_SESSION['level'] == 1) {
			$query = 	"SELECT ".PARAMS.".*,".PAGES.".NAME FROM ".PARAMS.",".PAGES.
					" WHERE ".PARAMS.".ID = 1 AND ".PAGES.".ID = ".PARAMS.".PAGEID";
			$query = $this->q($query);
			$dat = mysql_fetch_assoc($query);
			$content = $this->h->input("hidden","paramId",$dat['ID']);
			$content .= $this->h->input("hidden","update",1);
			$content .= $this->h->p($this->tr->wsb("page name in use for home is")."\"".$this->h->b($dat['NAME'])."\"");
			$content .= $this->h->p($this->tr->wsb("select home page").$this->list_pages_select($dat['PAGEID'],"catId"));
			// $content .= $this->h->p(" select sandbox page ".$this->list_pages_select($dat['SANDBOXID'],"sandBoxId") );
			$content .= $this->h->p($this->tr->wsb("website administrator mail").$this->h->input("text","mail",$dat['MAIL']));
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->wsb("update all")));
			$form = $content;
			$result = $this->h->form($form,"page","post","admin.php?action=admin_home");
			return $result;
		}
	}
	public function update_site_params() {
		$query = "UPDATE ".PARAMS." SET PAGEID = '".$_POST['catId'].
		"',MAIL = '".$this->h->safe($_POST['mail']).
		"',SANDBOXID = '".$this->h->num($_POST['sandBoxId'])."' WHERE ID = 1";
		$query = $this->q($query);
		$query = "UPDATE ".PAGES." SET HIDE = 1 "." WHERE ID = ".$this->h->num($_POST['sandBoxId']);
		$query = $this->q($query);
		$result = $this->h->h3("params updated !");
		return $result;
	}
	public function list_pages_select($catId,$name) {
		$query = "SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES;
		$query = $this->q($query);
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $catId) {
				$elements[$line['NAME']] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$result = $this->h->select($elements,$name,$catId);
		return $result;
	}
}
?>

==> ulyxex.0.1.0.with-tinyMce.zip: pages/code/admin_home.php <==
<?php
class Site extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function site_params() {
		if ($_SESSION['level'] == 1) {
			$query = 	"SELECT ".PARAMS.".*,".PAGES.".NAME FROM ".PARAMS.",".PAGES.
					" WHERE ".PARAMS.".ID = 1 AND ".PAGES.".ID = ".PARAMS.".PAGEID";
			$query = $this->q($query);
			$dat = mysql_fetch_assoc($query);
			$content = $this->h->input("hidden","paramId",$dat['ID']);
			$content .= $this->h->input("hidden","update",1);
			$content .= $this->h->p($this->tr->wsb("page name in use for home is")."\"".$this->h->b($dat['NAME'])."\"");
			$content .= $this->h->p($this->tr->wsb("select home page").$this->list_pages_select($dat['PAGEID'],"pageId"));
			// $content .= $this->h->p(" select sandbox page ".$this->list_pages_select($dat['SANDBOXID'],"sandBoxId") );
			$content .= $this->h->p($this->tr->wsb("website administrator mail").$this->h->input("text","mail",$dat['MAIL']));
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->wsb("update all")));
			$form = $content;
			$result = $this->h->form($form,"page","post","admin.php?action=admin_home");
			return $result;
		}
	}
	public function update_site_params() {
		$query = "UPDATE ".PARAMS." SET PAGEID = '".$_POST['pageId'].
		"',MAIL = '".$this->h->safe($_POST['mail']).
		"',SANDBOXID = '".$this->h->num($_POST['sandBoxId'])."' WHERE ID = 1";
		$query = $this->q($query);
		$query = "UPDATE ".PAGES." SET HIDE = 1 "." WHERE ID = ".$this->h->num($_POST['sandBoxId']);
		$query = $this->q($query);
		$result = $this->h->h3("params updated !");
		return $result;
	}
	public function list_pages_select($pageId,$name) {
		$query = "SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES;
		$query = $this->q($query);
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $pageId) {
				$elements[$line['NAME']] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$result = $this->h->select($elements,$name,$pageId);
		return $result;
	}
}
?>
